package dk.nsp.api

import android.content.Context
import dk.nsp.api.auth.AuthController
import dk.nsp.api.knowledge.ILexiconController
import dk.nsp.api.knowledge.LexiconApi
import dk.nsp.api.knowledge.LexiconControllerImpl
import dk.nsp.api.util.CustomOkHttpClient
import dk.nsp.api.util.converters.JsonConfig
import dk.nsp.mingraviditet.api.BuildConfig
import retrofit2.Retrofit

class BackendApiLayerImpl(context: Context) : IBackendApiLayer {

    override val lexiconController: ILexiconController by lazy {
        LexiconControllerImpl(lexiconApi)
    }

    private val backendUrl: String = BuildConfig.BackendUrl

    private val authController = AuthController.get(context.applicationContext)

    private val backendRetrofitInstance: Retrofit by lazy {
        Retrofit.Builder()
            .baseUrl(backendUrl)
            .addConverterFactory(JsonConfig.converterFactory)
            .client(
                CustomOkHttpClient.getSecureClientWithAuth(
                    authController
                )
            )
            .build()
    }


    private val lexiconApi by lazy {
        backendRetrofitInstance.create(
            LexiconApi::class.java
        )
    }

}