package dk.nsp.api.knowledge

import dk.nsp.api.knowledge.models.ArticleCatalogueDTO
import dk.nsp.api.knowledge.models.ChecklistDTO
import dk.nsp.api.knowledge.models.ChecklistItemDTO
import dk.nsp.api.knowledge.models.LexiconCategoryDTO
import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.tryOrFailed
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class LexiconControllerImpl(private val api: LexiconApi) : ILexiconController {
    override fun getChecklists(scope: CoroutineScope): Deferred<ResultWrapper<List<ChecklistDTO>>> =
        scope.asyncIO {
            tryOrFailed {
                api.getChecklists()
            }
        }

    override fun getLexiconCategories(scope: CoroutineScope): Deferred<ResultWrapper<List<LexiconCategoryDTO>>> =
        scope.asyncIO {
            tryOrFailed {
                api.getCategories()
            }
        }

    override fun getArticlesFor(
        scope: CoroutineScope,
        category: String
    ): Deferred<ResultWrapper<ArticleCatalogueDTO>> = scope.asyncIO {
        tryOrFailed {
            api.getArticles(0, null, null, listOf(category), null)
        }
    }

    override fun searchForArticles(
        scope: CoroutineScope,
        searchQuery: String
    ): Deferred<ResultWrapper<ArticleCatalogueDTO>> = scope.asyncIO {
        tryOrFailed {
            api.getArticles(0, null, null, null, searchQuery)
        }
    }

    override fun toggleChecklistItem(
        scope: CoroutineScope,
        checklist: ChecklistDTO,
        checklistItem: ChecklistItemDTO
    ): Deferred<ResultWrapper<ChecklistItemDTO>> =
        scope.asyncIO {
            tryOrFailed {
                api.setChecklistItem(checklist.id, checklistItem.id, !checklistItem.value)
            }
        }
}