package dk.nsp.api.knowledge

import android.content.res.Resources
import dk.nsp.api.knowledge.models.*
import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.shared.Failed
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.Success
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred
import kotlinx.coroutines.delay
import org.joda.time.DateTime
import java.util.*

class LexiconControllerMock : ILexiconController {
    private var checklists = mutableListOf(
        ChecklistDTO(
            "checklistId0",
            "Fødetasken",
            "Du kan starte med at købe det allermest nødvendige og så afvente, hvad du kan låne købe brugt, og hvad du evt. får i barselsgave er også en god idé at tænke på størrelsen af det, du køber. Nyfødte vokser meget hurtigt, så der skal helst ikke være for meget i str. 50. Undgå også at købe toj og overtoj med snorelukning, der kan kvæle barnet.",
            mutableListOf(
                ChecklistItemDTO("itemId0", "Mad og drikke", "Test description", false),
                ChecklistItemDTO("itemId1", "Kamera og oplader", null, true)
            )
        ),
        ChecklistDTO(
            "checklistid",
            "Test kort",
            null,
            mutableListOf(
                ChecklistItemDTO("itemId2", "1", null, false),
                ChecklistItemDTO("itemId3", "2", null, false),
                ChecklistItemDTO("itemId4", "3", null, false),
                ChecklistItemDTO("itemId5", "4", null, false),
                ChecklistItemDTO("itemId6", "5", null, false),
                ChecklistItemDTO("itemId7", "6", null, false)
            )
        )
    )

    override fun getChecklists(scope: CoroutineScope): Deferred<ResultWrapper<List<ChecklistDTO>>> =
        scope.asyncIO {
            Success(checklists)
        }

    private val categories = listOf(
        LexiconCategoryDTO(
            UUID.randomUUID().toString(),
            "http://clausr.dk/smertelindring.png",
            "Uge for uge",
            "Beskrivelse",
            4
        ),
        LexiconCategoryDTO(
            UUID.randomUUID().toString(),
            "http://clausr.dk/smertelindring.png",
            "Sundhed",
            "Beskrivelse",
            5
        ),
        LexiconCategoryDTO(
            UUID.randomUUID().toString(),
            "http://clausr.dk/smertelindring.png",
            "Undersøgelser",
            "Beskrivelse",
            4
        ),
        LexiconCategoryDTO(
            UUID.randomUUID().toString(),
            "http://clausr.dk/smertelindring.png",
            "Tanker",
            "Beskrivelse",
            5
        ),
        LexiconCategoryDTO(
            UUID.randomUUID().toString(),
            "http://clausr.dk/smertelindring.png",
            "Smertelindring",
            "Beskrivelse",
            1
        )
    )

    override fun getLexiconCategories(scope: CoroutineScope): Deferred<ResultWrapper<List<LexiconCategoryDTO>>> =
        scope.asyncIO {
            Success(categories)
        }

    override fun getArticlesFor(
        scope: CoroutineScope,
        category: String
    ): Deferred<ResultWrapper<ArticleCatalogueDTO>> = scope.asyncIO {
        Success(
            ArticleCatalogueDTO(
                0, 1, listOf(
                    ArticleDTO(
                        DateTime(),
                        DateTime(),
                        "",
                        "Mad og drikke",
                        listOf(),
                        "Er der noget bedre tidspunkt at begynde at spise sundere, end når du er gravid? At spise er sundt at leve er sundt..",
                        listOf(),
                        listOf()
                    )
                )
            )
        )
    }

    override fun searchForArticles(
        scope: CoroutineScope,
        searchQuery: String
    ): Deferred<ResultWrapper<ArticleCatalogueDTO>> = scope.asyncIO {
        val searchHits = mutableListOf<ArticleDTO>()

        if (searchHits.isEmpty()) {
            Failed(Exception("No hits"))
        } else {
            Success(ArticleCatalogueDTO(0, 1, searchHits))
        }

    }

    override fun toggleChecklistItem(
        scope: CoroutineScope,
        checklist: ChecklistDTO,
        checklistItem: ChecklistItemDTO
    ): Deferred<ResultWrapper<ChecklistItemDTO>> = scope.asyncIO {
        delay(150)

        val matchingChecklist = checklists.firstOrNull { it.id == checklist.id }

        if (matchingChecklist != null) {
            val foundItem = matchingChecklist.items.firstOrNull { it.id == checklistItem.id }

            if (foundItem != null) {
                val indexOfItem = matchingChecklist.items.indexOf(foundItem)
                val toggledItem = foundItem.copy(value = !foundItem.value)

                val copyOfList = matchingChecklist.items.toMutableList()

                copyOfList.removeAt(indexOfItem)
                copyOfList.add(indexOfItem, toggledItem)

                val newChecklist = checklist.copy(items = copyOfList)

                val indexOfChecklist = checklists.indexOfFirst { it.id == checklist.id }
                checklists[indexOfChecklist] = newChecklist

                Success(toggledItem)
            }

        } else {
            Failed(Resources.NotFoundException("Could not find checklist"))
        }

        Failed(NotImplementedError())
    }
}