package dk.nsp.mingraviditet

import android.app.Application
import androidx.appcompat.app.AppCompatDelegate
import dagger.hilt.android.HiltAndroidApp
import io.tpa.tpalib.CrashHandling
import io.tpa.tpalib.LoggingDestination
import io.tpa.tpalib.TPA
import io.tpa.tpalib.TpaConfiguration
import timber.log.Timber

@HiltAndroidApp
open class App : Application() {

    override fun onCreate() {
        super.onCreate()
        setupTpa()
        setupTimber()

        AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_NO)
    }

    private fun setupTimber() {
        if (BuildConfig.DEBUG) {
            Timber.plant(Timber.DebugTree())
        }
    }

    // TODO Set projectUuid and serverUrl
    private fun setupTpa() {
        val config =
            TpaConfiguration.Builder("20338f66-19ea-4a2d-a1eb-494520fe4a40", "https://insp.tpa.io/")
                .setAutomaticUpdateCheckEnabled(BuildConfig.FLAVOR != "googlePlay" && !BuildConfig.DEBUG) // This check should only run on TPA release versions
                .setLoggingDestination(LoggingDestination.REMOTE)
                .setCrashHandling(CrashHandling.ALWAYS_SEND)
                .basicUpdateDialog(false)
                .enableAnalytics(true)
                .build()

        TPA.initialize(this, config)
    }
}
