package dk.nsp.mingraviditet.ui

import android.os.Bundle
import android.view.WindowManager
import androidx.appcompat.app.AppCompatActivity
import androidx.core.view.WindowCompat
import androidx.lifecycle.lifecycleScope
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.App
import dk.nsp.mingraviditet.util.TimeoutActivityHelper

@AndroidEntryPoint
abstract class BaseActivity : AppCompatActivity() {

    private val app get() = applicationContext as App

    private val timeoutActivityHelper by lazy {
        TimeoutActivityHelper(lifecycleScope, this)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        WindowCompat.setDecorFitsSystemWindows(window, true)

        timeoutActivityHelper.onCreate(savedInstanceState)

//        initializeScreenSecurity()
    }

    private fun initializeScreenSecurity() {
//        if (SharedPrefs.getInstance(this).screenSecurity) {
        window.addFlags(WindowManager.LayoutParams.FLAG_SECURE)
//        } else {
//            window.clearFlags(WindowManager.LayoutParams.FLAG_SECURE)
//        }
    }

    override fun onDestroy() {
        timeoutActivityHelper.onDestroy()
        super.onDestroy()
    }

    override fun onUserInteraction() {
        timeoutActivityHelper.onUserInteraction()
    }

    override fun onResume() {
        super.onResume()
        timeoutActivityHelper.onResume()
        initializeScreenSecurity()
    }


    override fun onSaveInstanceState(outState: Bundle) {
        super.onSaveInstanceState(outState)
        timeoutActivityHelper.onSaveInstanceState(outState)
    }

}
