package dk.nsp.mingraviditet.ui.adapterviews

import androidx.recyclerview.widget.RecyclerView
import dk.nsp.mingraviditet.databinding.HorizontalRecyclerSectionBinding
import dk.nsp.mingraviditet.ui.common.TextModel
import dk.nsp.mingraviditet.util.android.PercentageWidthLinearLayoutManager
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView

data class HorizontalRecyclerSectionData(
    val title: TextModel,
    val items: List<RecyclerAdapterView<*>>
)

class HorizontalRecyclerSectionView(val data: HorizontalRecyclerSectionData) :
    RecyclerAdapterView<HorizontalRecyclerSectionBinding> {

    private val listAdapter by lazy {
        DelegatingListAdapter()
    }

    override fun bindData(viewHolder: BindingViewHolder<HorizontalRecyclerSectionBinding>) {
        val context = viewHolder.binding.root.context

        viewHolder.binding.sectionTitle = data.title

        viewHolder.binding.recyclerView.apply {
            layoutManager =
                PercentageWidthLinearLayoutManager(context, RecyclerView.HORIZONTAL, false, 0.4F)
            adapter = listAdapter
            overScrollMode = RecyclerView.OVER_SCROLL_NEVER
        }

        listAdapter.submitList(data.items)
    }

    override val createHolderFunction: DelegationListAdapterInflater<HorizontalRecyclerSectionBinding> =
        HorizontalRecyclerSectionBinding::inflate

}