package dk.nsp.mingraviditet.ui.main.journal

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.constraintlayout.motion.widget.MotionLayout
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.commonsense.android.kotlin.views.extensions.setup
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentJournalBinding
import dk.nsp.mingraviditet.ui.widgets.EmptyStateFullHeight
import dk.nsp.mingraviditet.util.android.motionlayout.MotionLayoutStateEnum
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.handleToolbarState
import dk.nsp.mingraviditet.util.extensions.setupToolbarStateListener

class JournalFragment : Fragment() {
    private lateinit var binding: FragmentJournalBinding

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private var state: MotionLayoutStateEnum = MotionLayoutStateEnum.Start
        set(value) {
            field = value
            (binding.root as MotionLayout).handleToolbarState(value)
        }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        binding = FragmentJournalBinding.inflate(inflater, null, false)
        binding.toolbarTitle.setText(R.string.bottom_navigation_title_journal)
        setupToolbarState()

        binding.recyclerview.setup(
            adapter,
            LinearLayoutManager(context, RecyclerView.VERTICAL, false)
        )

        adapter.submitList(listOf(EmptyStateFullHeight()))


        return binding.root
    }

    private fun setupToolbarState() {
        setupToolbarStateListener(binding.root) { newState ->
            state = newState
        }

        (binding.root as MotionLayout).handleToolbarState(state)
    }
}