package dk.nsp.mingraviditet.ui.main.knowledge.article

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.navArgs
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import com.commonsense.android.kotlin.views.extensions.setup
import dk.nsp.domain.knowledge.ArticleContent
import dk.nsp.mingraviditet.databinding.FragmentKnowledgeArticleBinding
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import org.joda.time.DateTime

class KnowledgeArticleFragment : Fragment() {

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private val args: KnowledgeArticleFragmentArgs by navArgs()

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        val binding = FragmentKnowledgeArticleBinding.inflate(inflater, container, false)

        binding.toolbar.setNavigationOnClickListener { onBackPressed() }

        binding.recyclerView.setup(
            adapter,
            LinearLayoutManager(context, RecyclerView.VERTICAL, false)
        )

        val adapterViews = mutableListOf<RecyclerAdapterView<*>>()

        adapterViews.add(createExcerptRow(args.article.excerpt))
        adapterViews.addAll(createParagraphCards(args.article.content))
        adapterViews.add(createLastUpdatedRow(args.article.lastUpdateDate))

        binding.toolbar.title = args.article.title

        adapter.submitList(adapterViews)

        return binding.root
    }

    private fun createExcerptRow(excerpt: String): ArticleExcerptRow =
        ArticleExcerptRow(excerpt)

    private fun createParagraphCards(articleContents: List<ArticleContent>): List<ArticleParagraphCardRow> {
        return articleContents.map {
            ArticleParagraphCardRow(it)
        }
    }

    private fun createLastUpdatedRow(lastUpdatedDate: DateTime): ArticleLastUpdatedDateRow {
        return ArticleLastUpdatedDateRow(lastUpdatedDate)
    }
}