package dk.nsp.mingraviditet.ui.main.knowledge.articles

import androidx.hilt.lifecycle.ViewModelInject
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.commonsense.android.kotlin.base.extensions.coroutines.launchIO
import dagger.hilt.android.scopes.ActivityScoped
import dk.nsp.domain.knowledge.Article
import dk.nsp.domain.knowledge.LexiconCategory
import dk.nsp.domain.repository.LexiconRepository
import dk.nsp.mingraviditet.ui.main.knowledge.viewbinding.ArticleCardBindingModel
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.toSingleEvent
import dk.nsp.mingraviditet.util.livedata.SingleEvent
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import timber.log.Timber

@ActivityScoped
class KnowledgeArticlesViewModel @ViewModelInject constructor(
    private val lexiconRepository: LexiconRepository
) : ViewModel() {

    private val _onData: MutableLiveData<List<RecyclerAdapterView<*>>> = MutableLiveData()
    val onData: LiveData<List<RecyclerAdapterView<*>>> = _onData

    private val _onArticleClicked: MutableLiveData<SingleEvent<Article>> = MutableLiveData()
    val onArticleClicked: LiveData<SingleEvent<Article>> = _onArticleClicked

    init {
        Timber.d("InitViewModel $this")
    }

    fun getArticlesForCategory(lexiconCategory: LexiconCategory) {
        viewModelScope.launchIO {
            val catalogue = lexiconRepository.getArticlesFor(this, lexiconCategory).await()

            when (catalogue) {
                is Success -> {
                    val articles = catalogue.value.content ?: return@launchIO

                    val rowsToShow = mutableListOf<RecyclerAdapterView<*>>()
                    rowsToShow.add(ArticlesHeader(lexiconCategory))
                    val articlesRows = articles.map { article ->
                        ArticleCard(ArticleCardBindingModel(article) {
                            _onArticleClicked.postValue(article.toSingleEvent())
                        })
                    }
                    rowsToShow.addAll(articlesRows)

                    _onData.postValue(rowsToShow)

                }
                is Failed -> {

                }
            }
        }
    }

}