package dk.nsp.mingraviditet.util.extensions

import android.content.Context
import android.net.ConnectivityManager
import android.net.NetworkCapabilities
import androidx.biometric.BiometricManager


/**
 * Checks if biometrics can be used for authentication
 * @receiver Context
// - https://android-developers.googleblog.com/2019/10/one-biometric-api-over-all-android.html
 * @return Boolean True if hardware is present and user has enrolled in biometrics, otherwise false
 */
fun Context.isBiometricAvailable(): Boolean {
    // TODO: Ensure that this works for low end device (E.g. below Android P) - MFJ (31/03/2020)
    // - so android api 21, 22 is not supported.
    // source: https://developer.android.com/training/sign-in/biometric-auth#available
    return BiometricManager.from(this).canAuthenticate() == BiometricManager.BIOMETRIC_SUCCESS
}


fun Context.isInternetAvailable(): Boolean {
    val connectivityManager = getSystemService(Context.CONNECTIVITY_SERVICE) as ConnectivityManager

    val activeNetwork = connectivityManager.activeNetwork ?: return false
    val capabilities = connectivityManager.getNetworkCapabilities(activeNetwork) ?: return false

    return capabilities.hasCapability(NetworkCapabilities.NET_CAPABILITY_INTERNET)
}