package dk.nsp.domain.knowledge

import android.os.Parcelable
import dk.nsp.api.knowledge.models.ArticleCatalogueDTO
import dk.nsp.api.knowledge.models.ArticleContentDTO
import dk.nsp.api.knowledge.models.ArticleDTO
import kotlinx.parcelize.Parcelize
import org.joda.time.DateTime

@Parcelize
data class Article(
    val publicationDate: DateTime,
    val lastUpdateDate: DateTime,
    val id: String,
    val title: String,
    val content: List<ArticleContent>,
    val excerpt: String,
    val categories: List<String>,
    val tags: List<String>
) : Parcelable

@Parcelize
data class ArticleContent(
    val title: String,
    val content: String
) : Parcelable

@Parcelize
data class ArticleCatalogue(
    val currentPage: Int,
    val numberOfPages: Int,
    val content: List<Article>?
) : Parcelable

fun ArticleCatalogueDTO.toDomainModel(): ArticleCatalogue {
    return ArticleCatalogue(currentPage, numberOfPages, content?.map { it.toDomainModel() })
}

fun ArticleDTO.toDomainModel(): Article {
    return Article(
        publicationDate,
        lastUpdateDate,
        id,
        title,
        content.toDomainModel(),
        excerpt,
        categories,
        tags
    )
}

fun List<ArticleContentDTO>.toDomainModel(): List<ArticleContent> {
    return this.map { ArticleContent(it.title, it.content) }
}