package dk.nsp.domain.knowledge

import android.os.Parcelable
import dk.nsp.api.knowledge.models.ChecklistDTO
import dk.nsp.api.knowledge.models.ChecklistItemDTO
import kotlinx.parcelize.Parcelize

@Parcelize
data class Checklist(
    val id: String,
    val title: String,
    val description: String?,
    val items: List<ChecklistItem>
) : Parcelable {
    fun checkedItems() = items.filter { it.value }
    fun uncheckedItems() = items.filterNot { it.value }

    fun completeness(): Float {
        return if (items.isNotEmpty()) {
            (checkedItems().size.toFloat() / items.size) * 100
        } else {
            0F
        }
    }

    fun completenessAsDivision(): String {
        return "${items.filter { it.value }.size} / ${items.size}"
    }

    fun getPercentageAsString(): String {
        return "${completeness().toInt()}%"
    }
}

@Parcelize
data class ChecklistItem(
    val id: String,
    val title: String,
    val description: String?,
    val value: Boolean
) : Parcelable

fun List<ChecklistDTO>.toDomainModel(): List<Checklist> {
    return this.map {
        Checklist(
            it.id,
            it.title,
            it.text,
            it.items.map { it.toDomainModel() })
    }
}

fun Checklist.toServerModel(): ChecklistDTO {
    return ChecklistDTO(id, title, description, items.map { it.toServerModel() })
}

fun ChecklistItemDTO.toDomainModel(): ChecklistItem {
    return ChecklistItem(id, title, text, value)
}

fun ChecklistItem.toServerModel(): ChecklistItemDTO {
    return ChecklistItemDTO(id, title, description, value)
}